==> plazma_chess-1.0.1.tar.gz: plazma_chess-1.0.1/README.md <==
#   P l a z m a   C h e s s   E n g i n e 
 
 
 
 # #   I n   d e v e l o p m e n t ! 
 
 
 
 # # #   T h i s   i s   a   b a s i c   c h e s s   e n g i n e   b a s e d   o f f   o f   t h e   [ p y t h o n - c h e s s ] ( h t t p s : / / g i t h u b . c o m / n i k l a s f / p y t h o n - c h e s s )   l i b r a r y 
 
 
 
 # # # #   T h e   e n g i n e   c o m e s   w i t h   a   c l i e n t   w h i c h   s u p p o r t s   m u l t i p l a y e r ,   s i n g l e p l a y e r   a n d   b o t   c h e s s   m a t c h e s ! 
 
 
 
 T r y   r u n n i n g   ` ` ` p y t h o n   e x a m p l e . p y ` ` `   t o   t e s t   t h e   e n g i n e   o r   j u s t   p l a y   w i t h   f r i e n d s 
 
 
 
 # #   D o c u m e n t a t i o n 
 
 # # #   S e t t i n g   u p   t h e   b o a r d 
 
 ` ` ` p y t h o n 
 
 i m p o r t   e n g i n e   #   I m p o r t   t h e   p l a z m a - c h e s s   m o d u l e 
 
 
 
 c h e s s E n g i n e   =   e n g i n e . E n g i n e ( )   #   C r e a t e   i n s t a n c e   o f   t h e   E n g i n e   c l a s s 
 
 ` ` ` 
 
 
 
 T h i s   w i l l   i n i t i a l i z e   t h e   e n g i n e   c l a s s   w h i c h   c o n t a i n s   a l l   o f   t h e   i n f o r m a t i o n   o f   t h e   b o a r d . 
 
 A l l   p i e c e s   w i l l   b e   s e t   t o   n o r m a l   c h e s s   s t a r t i n g   p o s i t i o n s . 
 
 
 
 # # #   A c e s s i n g   t h e   b o a r d 
 
 ` ` ` p y t h o n 
 
 i m p o r t   e n g i n e   #   I m p o r t   t h e   p l a z m a - c h e s s   m o d u l e 
 
 
 
 c h e s s E n g i n e   =   e n g i n e . E n g i n e ( )   #   C r e a t e   i n s t a n c e   o f   t h e   E n g i n e   c l a s s 
 
 p r i n t ( c h e s s E n g i n e . b o a r d . b o a r d )   #   A c c e s s   t h e   b o a r d   c l a s s   s t o r e d   i n   t h e   e n g i n e   c l a s s   a n d   g e t   t h e   b o a r d   l i s t 
 
 
 
 #   E x a m p l e   o u t p u t   o f   s t a r t i n g   p o s i t i o n s 
 
 " " " [ [ 1 0 ,   8 ,   9 ,   1 1 ,   1 2 ,   9 ,   8 ,   1 0 ] , 
 
         [ 7 ,   7 ,   7 ,   7 ,   7 ,   7 ,   7 ,   7 ] , 
 
         [ 0 ,   0 ,   0 ,   0 ,   0 ,   0 ,   0 ,   0 ] , 
 
         [ 0 ,   0 ,   0 ,   0 ,   0 ,   0 ,   0 ,   0 ] , 
 
         [ 0 ,   0 ,   0 ,   0 ,   0 ,   0 ,   0 ,   0 ] , 
 
         [ 0 ,   0 ,   0 ,   0 ,   0 ,   0 ,   0 ,   0 ] , 
 
         [ 1 ,   1 ,   1 ,   1 ,   1 ,   1 ,   1 ,   1 ] , 
 
         [ 4 ,   2 ,   3 ,   5 ,   6 ,   3 ,   2 ,   4 ] ] " " " 
 
 ` ` ` 
 
 T o   A c c e s s   t h e   b o a r d   c l a s s ,   a n d   t h e   b o a r d   l i s t   w i t h i n   t h a t   y o u   n e e d   t o   u s e   t h e   e n g i n e   c l a s s . 
 
 T h i s   i s   b e c a u s e   w h e n   t h e   e n g i n e   c l a s s   i s   i n i t i a l i z e d   i t   a l s o   i n i t i a l i z e s   t h e   b o a r d . 
 
 
 
 # # #   G e n e r a t i n g   m o v e s 
 
 ` ` ` p y t h o n 
 
 i m p o r t   e n g i n e   #   I m p o r t   t h e   p l a z m a - c h e s s   m o d u l e 
 
 
 
 c h e s s E n g i n e   =   e n g i n e . E n g i n e ( )   #   C r e a t e   i n s t a n c e   o f   t h e   E n g i n e   c l a s s 
 
 
 
 l e g a l M o v e s   =   c h e s s E n g i n e . g e n e r a t e M o v e s ( ( 4 ,   6 ) )   #   G e t   t h e   l e g a l   m o v e s   f o r   t h e   k i n g s   p a w n 
 
 ` ` ` 
 
 T o   g e t   t h e   l e g a l   m o v e s   f o r   a   p i e c e   y o u   j u s t   n e e d   t o   s p e c i f y   t h e   c o o r d i n a t e s   o f   t h e   p i e c e   a n d   c a l l   t h e   ` g e n e r a t e M o v e s `   f u n c t i o n   i n   t h e   e n g i n e   c l a s s ,   p a s s i n g   i n   t h o s e   c o o r d i n a t e s . 
 
 
 
 # # #   F i n d i n g   p i e c e s 
 
 ` ` ` p y t h o n 
 
 i m p o r t   e n g i n e   #   I m p o r t   t h e   p l a z m a - c h e s s   m o d u l e 
 
 
 
 c h e s s E n g i n e   =   e n g i n e . E n g i n e ( )   #   C r e a t e   i n s t a n c e   o f   t h e   E n g i n e   c l a s s 
 
 
 
 p o s   =   a n y _ p i e c e s _ p o s i t i o n 
 
 
 
 p r i n t ( c h e s s E n g i n e . b o a r d . p i e c e A t ( p o s ) )   #   C a l l   t h e   ' p i e c e A t '   f u n c t i o n   i n   t h e   b o a r d 
 
 #   P r i n t s : 
 
 #       b o o l   - >   F o u n d   a   p i e c e 
 
 #       i n t   - >   P i e c e   v a l u e   ( 0   i f   n o   p i e c e ) 
 
 ` ` ` 
 
 T o   c h e c k   i f   a   p i e c e   i s   o n   a   s p e c i f i c   p a r t   o f   t h e   b o a r d   y o u   c a n   e i t h e r   a c c e s s   t h e   b o a r d   l i s t   m a n u a l l y   o r   u s e   t h e   ` p i e c e A t `   f u n c t i o n   i n   t h e   b o a r d   c l a s s . 
 
 
 
 # # #   M o v i n g   p i e c e s 
 
 ` ` ` p y t h o n 
 
 i m p o r t   e n g i n e   #   I m p o r t   t h e   p l a z m a - c h e s s   m o d u l e 
 
 
 
 c h e s s E n g i n e   =   e n g i n e . E n g i n e ( )   #   C r e a t e   i n s t a n c e   o f   t h e   E n g i n e   c l a s s 
 
 
 
 p o s   =   c u r r e n t _ p i e c e _ p o s i t i o n 
 
 n e w P o s   =   n e w _ p i e c e _ p o s i t i o n 
 
 
 
 s t a t u s   =   c h e s s E n g i n e . m o v e ( p o s ,   n e w P o s )   #   C a l l   t h e   m o v e   f u n c t i o n   i n   t h e   e n g i n e 
 
 
 
 #   I f   s t a t u s   =   0   t h e   m o v e   w a s   s u c c e s s f u l l . 
 
 #   I f   s t a t u s   =   1   t h e   m o v e   e n d e d   i n   c h e c k m a t e . 
 
 #   I f   a n   I l l e g a l   M o v e   e r r o r   s u r f a c e s   t h e   m o v e   w a s   u n s u c c e s s f u l l . 
 
 ` ` ` 
 
 T o   m o v e   p i e c e s   s i m p l y   c a l l   t h e   m o v e   f u n c t i o n   i n   t h e   e n g i n e   c l a s s .   I t   w i l l   n o t   a l l o w   i l l e g a l   m o v e s   t o   b e   p l a y e d   a n d   i t   u s e s   t h e   s a m e   ` g e n e r a t e M o v e s `   f u n c t i o n   t o   v a l i d a t e   m o v e s . 
 
 
 
 N e i t h e r   t h e   ` g e n e r a t e M o v e s `   f u n c t i o n   o r   t h e   ` m o v e `   f u n c t i o n   w i l l   r e t u r n   m o v e s   t h a t   m a y   r e s u l t   i n   a   c h e c k . 
 
 
 
 # # #   B o t s 
 
 B o t   s u p p o r t   i s   n o t   f u l l y   i m p l e m e n t e d   y e t   s o   c r e a t i n g   b o t s   r e q u i r e s   a   l i t t l e   m o r e   w o r k   t h a n   e x p e c t e d . 
 
 
 
 G e n e r a t i n g   m o v e s   i s   a   l i t t l e   e a s i e r   t h a n k s   t o   t h e   i n d i v i d u a l   m o v e   g e n e r a t i o n   f u n c t i o n s . 
 
 
 
 T h e s e   i n c l u d e : 
 
 *   ` g e n e r a t e P a w n M o v e s ` 
 
 *   ` g e n e r a t e K n i g h t M o v e s ` 
 
 *   ` g e n e r a t e S l i d i n g M o v e s ` 
 
 *   ` g e n e r a t e D i a g o n a l M o v e s ` 
 
 *   ` g e n e r a t e K i n g M o v e s ` 
 
 
 
 T h i s   a l l o w s   y o u   t o   g e n e r a t e   m o v e s   w i t h   m o r e   s p e c i a l l i t y   a n d   p r e s i c i o n . 
 
 
 
 T h e s e   f u n c t i o n s   a l l   t a k e   t h e   s a m e   a r g u m e n t ,   ` p o s `   w h i c h   d e f i n e s   t h e   p i e c e   p o s i t i o n . 
 
 
 
 T h e s e   f u n c t i o n s   d o   n o t   t a k e   c h e c k s   i n t o   a c c o u n t   s o   i l l e g a l   m o v e   e r r o r s   a r e   a   r i s k . 
 
 
 
 Y o u   c a n   r e m e d y   t h i s   b y   u s i n g   t h e   ` i n C h e c k `   f u n c t i o n   w h i c h   t a k e s   a   ` t u r n `   a r g u m e n t   a n d   a n d   o p t i o n a l   ` s q u a r e `   a r g u m e n t   w h i c h   i s   u s e d   t o   c h e c k   f o r   a   s p e c i f i c   p i e c e .   I t   r e t u r n s   ` T r u e `   o r   ` F a l s e `   i f   t h e   k i n g   i s   i n   c h e c k . 
 
 
 
 T o   b y p a s s   t h e   c h e c k   d e t e c t i o n   t h e r e   i s   a   f u n c t i o n   c a l l e d   ` _ _ m o v e W i t h o u t C h e c k ` .   T h i s   f u n c t i o n   i s   d a n g e r o u s   a s   i t   d e f i e s   t h e   r u l e s   o f   c h e s s .   I t   s h o u l d   o n l y   b e   u s e d   f o r   m o v e   g e n e r a t i o n   i n   b o t s   w h i c h   w i l l   g a r r e n t e e   f a s t e r   m o v e   g e n e r a t i o n . 

==> plazma_chess-1.2.0.tar.gz: plazma_chess-1.2.0/README.md <==
#   P l a z m a   C h e s s   E n g i n e 
 
 
 
 # #   I n   d e v e l o p m e n t ! 
 
 
 
 # # #   T h i s   i s   a   b a s i c   c h e s s   e n g i n e   b a s e d   o f f   o f   t h e   [ p y t h o n - c h e s s ] ( h t t p s : / / g i t h u b . c o m / n i k l a s f / p y t h o n - c h e s s )   l i b r a r y 
 
 
 
 # # # #   T h e   e n g i n e   h a s   a   [ c l i e n t ] ( h t t p s : / / g i t h u b . c o m / n i k l a s f / p y t h o n - c h e s s - c l i e n t )   w h i c h   s u p p o r t s   m u l t i p l a y e r ,   s i n g l e p l a y e r   a n d   b o t   c h e s s   m a t c h e s ! 
 
 
 
 # #   D o c u m e n t a t i o n 
 
 # # #   S e t t i n g   u p   t h e   b o a r d 
 
 ` ` ` p y t h o n 
 
 i m p o r t   e n g i n e   #   I m p o r t   t h e   p l a z m a - c h e s s   m o d u l e 
 
 
 
 c h e s s E n g i n e   =   e n g i n e . E n g i n e ( )   #   C r e a t e   i n s t a n c e   o f   t h e   E n g i n e   c l a s s 
 
 ` ` ` 
 
 
 
 T h i s   w i l l   i n i t i a l i z e   t h e   e n g i n e   c l a s s   w h i c h   c o n t a i n s   a l l   o f   t h e   i n f o r m a t i o n   o f   t h e   b o a r d . 
 
 A l l   p i e c e s   w i l l   b e   s e t   t o   n o r m a l   c h e s s   s t a r t i n g   p o s i t i o n s . 
 
 
 
 # # #   A c e s s i n g   t h e   b o a r d 
 
 ` ` ` p y t h o n 
 
 i m p o r t   e n g i n e   #   I m p o r t   t h e   p l a z m a - c h e s s   m o d u l e 
 
 
 
 c h e s s E n g i n e   =   e n g i n e . E n g i n e ( )   #   C r e a t e   i n s t a n c e   o f   t h e   E n g i n e   c l a s s 
 
 p r i n t ( c h e s s E n g i n e . b o a r d . b o a r d )   #   A c c e s s   t h e   b o a r d   c l a s s   s t o r e d   i n   t h e   e n g i n e   c l a s s   a n d   g e t   t h e   b o a r d   l i s t 
 
 
 
 #   E x a m p l e   o u t p u t   o f   s t a r t i n g   p o s i t i o n s 
 
 " " " [ [ 1 0 ,   8 ,   9 ,   1 1 ,   1 2 ,   9 ,   8 ,   1 0 ] , 
 
         [ 7 ,   7 ,   7 ,   7 ,   7 ,   7 ,   7 ,   7 ] , 
 
         [ 0 ,   0 ,   0 ,   0 ,   0 ,   0 ,   0 ,   0 ] , 
 
         [ 0 ,   0 ,   0 ,   0 ,   0 ,   0 ,   0 ,   0 ] , 
 
         [ 0 ,   0 ,   0 ,   0 ,   0 ,   0 ,   0 ,   0 ] , 
 
         [ 0 ,   0 ,   0 ,   0 ,   0 ,   0 ,   0 ,   0 ] , 
 
         [ 1 ,   1 ,   1 ,   1 ,   1 ,   1 ,   1 ,   1 ] , 
 
         [ 4 ,   2 ,   3 ,   5 ,   6 ,   3 ,   2 ,   4 ] ] " " " 
 
 ` ` ` 
 
 T o   A c c e s s   t h e   b o a r d   c l a s s ,   a n d   t h e   b o a r d   l i s t   w i t h i n   t h a t   y o u   n e e d   t o   u s e   t h e   e n g i n e   c l a s s . 
 
 T h i s   i s   b e c a u s e   w h e n   t h e   e n g i n e   c l a s s   i s   i n i t i a l i z e d   i t   a l s o   i n i t i a l i z e s   t h e   b o a r d . 
 
 
 
 # # #   G e n e r a t i n g   m o v e s 
 
 ` ` ` p y t h o n 
 
 i m p o r t   e n g i n e   #   I m p o r t   t h e   p l a z m a - c h e s s   m o d u l e 
 
 
 
 c h e s s E n g i n e   =   e n g i n e . E n g i n e ( )   #   C r e a t e   i n s t a n c e   o f   t h e   E n g i n e   c l a s s 
 
 
 
 l e g a l M o v e s   =   c h e s s E n g i n e . g e n e r a t e M o v e s ( ( 4 ,   6 ) )   #   G e t   t h e   l e g a l   m o v e s   f o r   t h e   k i n g s   p a w n 
 
 ` ` ` 
 
 T o   g e t   t h e   l e g a l   m o v e s   f o r   a   p i e c e   y o u   j u s t   n e e d   t o   s p e c i f y   t h e   c o o r d i n a t e s   o f   t h e   p i e c e   a n d   c a l l   t h e   ` g e n e r a t e M o v e s `   f u n c t i o n   i n   t h e   e n g i n e   c l a s s ,   p a s s i n g   i n   t h o s e   c o o r d i n a t e s . 
 
 
 
 # # #   F i n d i n g   p i e c e s 
 
 ` ` ` p y t h o n 
 
 i m p o r t   e n g i n e   #   I m p o r t   t h e   p l a z m a - c h e s s   m o d u l e 
 
 
 
 c h e s s E n g i n e   =   e n g i n e . E n g i n e ( )   #   C r e a t e   i n s t a n c e   o f   t h e   E n g i n e   c l a s s 
 
 
 
 p o s   =   a n y _ p i e c e s _ p o s i t i o n 
 
 
 
 p r i n t ( c h e s s E n g i n e . b o a r d . p i e c e A t ( p o s ) )   #   C a l l   t h e   ' p i e c e A t '   f u n c t i o n   i n   t h e   b o a r d 
 
 #   P r i n t s : 
 
 #       b o o l   - >   F o u n d   a   p i e c e 
 
 #       i n t   - >   P i e c e   v a l u e   ( 0   i f   n o   p i e c e ) 
 
 ` ` ` 
 
 T o   c h e c k   i f   a   p i e c e   i s   o n   a   s p e c i f i c   p a r t   o f   t h e   b o a r d   y o u   c a n   e i t h e r   a c c e s s   t h e   b o a r d   l i s t   m a n u a l l y   o r   u s e   t h e   ` p i e c e A t `   f u n c t i o n   i n   t h e   b o a r d   c l a s s . 
 
 
 
 # # #   M o v i n g   p i e c e s 
 
 ` ` ` p y t h o n 
 
 i m p o r t   e n g i n e   #   I m p o r t   t h e   p l a z m a - c h e s s   m o d u l e 
 
 
 
 c h e s s E n g i n e   =   e n g i n e . E n g i n e ( )   #   C r e a t e   i n s t a n c e   o f   t h e   E n g i n e   c l a s s 
 
 
 
 p o s   =   c u r r e n t _ p i e c e _ p o s i t i o n 
 
 n e w P o s   =   n e w _ p i e c e _ p o s i t i o n 
 
 
 
 s t a t u s   =   c h e s s E n g i n e . m o v e ( p o s ,   n e w P o s )   #   C a l l   t h e   m o v e   f u n c t i o n   i n   t h e   e n g i n e 
 
 
 
 #   I f   s t a t u s   =   0   t h e   m o v e   w a s   s u c c e s s f u l l . 
 
 #   I f   s t a t u s   =   1   t h e   m o v e   e n d e d   i n   c h e c k m a t e . 
 
 #   I f   a n   I l l e g a l   M o v e   e r r o r   s u r f a c e s   t h e   m o v e   w a s   u n s u c c e s s f u l l . 
 
 ` ` ` 
 
 T o   m o v e   p i e c e s   s i m p l y   c a l l   t h e   m o v e   f u n c t i o n   i n   t h e   e n g i n e   c l a s s .   I t   w i l l   n o t   a l l o w   i l l e g a l   m o v e s   t o   b e   p l a y e d   a n d   i t   u s e s   t h e   s a m e   ` g e n e r a t e M o v e s `   f u n c t i o n   t o   v a l i d a t e   m o v e s . 
 
 
 
 N e i t h e r   t h e   ` g e n e r a t e M o v e s `   f u n c t i o n   o r   t h e   ` m o v e `   f u n c t i o n   w i l l   r e t u r n   m o v e s   t h a t   m a y   r e s u l t   i n   a   c h e c k . 
 
 
 
 # # #   B o t s 
 
 B o t   s u p p o r t   i s   n o t   f u l l y   i m p l e m e n t e d   y e t   s o   c r e a t i n g   b o t s   r e q u i r e s   a   l i t t l e   m o r e   w o r k   t h a n   e x p e c t e d . 
 
 
 
 G e n e r a t i n g   m o v e s   i s   a   l i t t l e   e a s i e r   t h a n k s   t o   t h e   i n d i v i d u a l   m o v e   g e n e r a t i o n   f u n c t i o n s . 
 
 
 
 T h e s e   i n c l u d e : 
 
 *   ` g e n e r a t e P a w n M o v e s ` 
 
 *   ` g e n e r a t e K n i g h t M o v e s ` 
 
 *   ` g e n e r a t e S l i d i n g M o v e s ` 
 
 *   ` g e n e r a t e D i a g o n a l M o v e s ` 
 
 *   ` g e n e r a t e K i n g M o v e s ` 
 
 
 
 T h i s   a l l o w s   y o u   t o   g e n e r a t e   m o v e s   w i t h   m o r e   s p e c i a l l i t y   a n d   p r e s i c i o n . 
 
 
 
 T h e s e   f u n c t i o n s   a l l   t a k e   t h e   s a m e   a r g u m e n t ,   ` p o s `   w h i c h   d e f i n e s   t h e   p i e c e   p o s i t i o n . 
 
 
 
 T h e s e   f u n c t i o n s   d o   n o t   t a k e   c h e c k s   i n t o   a c c o u n t   s o   i l l e g a l   m o v e   e r r o r s   a r e   a   r i s k . 
 
 
 
 Y o u   c a n   r e m e d y   t h i s   b y   u s i n g   t h e   ` i n C h e c k `   f u n c t i o n   w h i c h   t a k e s   a   ` t u r n `   a r g u m e n t   a n d   a n d   o p t i o n a l   ` s q u a r e `   a r g u m e n t   w h i c h   i s   u s e d   t o   c h e c k   f o r   a   s p e c i f i c   p i e c e .   I t   r e t u r n s   ` T r u e `   o r   ` F a l s e `   i f   t h e   k i n g   i s   i n   c h e c k . 
 
 
 
 T o   b y p a s s   t h e   c h e c k   d e t e c t i o n   t h e r e   i s   a   f u n c t i o n   c a l l e d   ` _ _ m o v e W i t h o u t C h e c k ` .   T h i s   f u n c t i o n   i s   d a n g e r o u s   a s   i t   d e f i e s   t h e   r u l e s   o f   c h e s s .   I t   s h o u l d   o n l y   b e   u s e d   f o r   m o v e   g e n e r a t i o n   i n   b o t s   w h i c h   w i l l   g a r r e n t e e   f a s t e r   m o v e   g e n e r a t i o n . 
